==> suir-component-mapper-3.17.0.tgz: package/esm/checkbox/checkbox.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isReadOnly", "isDisabled", "isRequired", "label", "helperText", "description", "validateOnMount", "meta", "FormFieldGridProps", "HelperTextProps"],
    _excluded2 = ["options"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormCheckbox from "semantic-ui-react/dist/es/collections/Form/FormCheckbox.js";
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import MultipleChoiceList from './multiple-choice-list';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
export var SingleCheckbox = function SingleCheckbox(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  })),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      isRequired = _useFieldApi.isRequired,
      label = _useFieldApi.label,
      helperText = _useFieldApi.helperText,
      description = _useFieldApi.description,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      FormFieldGridProps = _useFieldApi.FormFieldGridProps,
      HelperTextProps = _useFieldApi.HelperTextProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormCheckbox, _extends({}, input, {
    required: isRequired,
    onChange: function onChange(_event, data) {
      input.onChange({
        target: data,
        type: 'checkbox'
      });
    },
    disabled: isDisabled || isReadOnly
  }, rest, {
    label: label,
    error: invalid && {
      content: meta.error || meta.submitError,
      pointing: 'left'
    }
  })));
};
SingleCheckbox.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  description: PropTypes.node,
  validateOnMount: PropTypes.bool,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};

var Checkbox = function Checkbox(_ref) {
  var options = _ref.options,
      props = _objectWithoutProperties(_ref, _excluded2);

  return options ? /*#__PURE__*/React.createElement(MultipleChoiceList, _extends({
    options: options
  }, props)) : /*#__PURE__*/React.createElement(SingleCheckbox, props);
};

Checkbox.propTypes = {
  options: PropTypes.array,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};
Checkbox.defaultProps = {
  FormFieldGridProps: {},
  HelperTextProps: {}
};
export default Checkbox;

==> suir-component-mapper-4.0.0.tgz: package/esm/checkbox/checkbox.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isReadOnly", "isDisabled", "isRequired", "label", "helperText", "description", "validateOnMount", "meta", "FormFieldGridProps", "HelperTextProps"],
    _excluded2 = ["options"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormCheckbox from "semantic-ui-react/dist/es/collections/Form/FormCheckbox.js";
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import MultipleChoiceList from './multiple-choice-list';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
export var SingleCheckbox = function SingleCheckbox(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  })),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      isRequired = _useFieldApi.isRequired,
      label = _useFieldApi.label,
      helperText = _useFieldApi.helperText,
      description = _useFieldApi.description,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      _useFieldApi$FormFiel = _useFieldApi.FormFieldGridProps,
      FormFieldGridProps = _useFieldApi$FormFiel === void 0 ? {} : _useFieldApi$FormFiel,
      _useFieldApi$HelperTe = _useFieldApi.HelperTextProps,
      HelperTextProps = _useFieldApi$HelperTe === void 0 ? {} : _useFieldApi$HelperTe,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormCheckbox, _extends({}, input, {
    required: isRequired,
    onChange: function onChange(_event, data) {
      input.onChange({
        target: data,
        type: 'checkbox'
      });
    },
    disabled: isDisabled || isReadOnly
  }, rest, {
    label: label,
    error: invalid && {
      content: meta.error || meta.submitError,
      pointing: 'left'
    }
  })));
};
SingleCheckbox.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  description: PropTypes.node,
  validateOnMount: PropTypes.bool,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};

var Checkbox = function Checkbox(_ref) {
  var options = _ref.options,
      props = _objectWithoutProperties(_ref, _excluded2);

  return options ? /*#__PURE__*/React.createElement(MultipleChoiceList, _extends({
    options: options
  }, props)) : /*#__PURE__*/React.createElement(SingleCheckbox, props);
};

Checkbox.propTypes = {
  options: PropTypes.array,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};
export default Checkbox;
